@@ -6,7 +6,7 @@ import subprocess
 
 from django.utils.translation import gettext_noop
 
-from plinth import action_utils, app
+from plinth import action_utils, app, kvstore
 from plinth.diagnostic_check import (DiagnosticCheck,
                                      DiagnosticCheckParameters, Result)
 from plinth.privileged import service as service_privileged
@@ -17,8 +17,9 @@ from . import privileged
 class Webserver(app.LeaderComponent):
     """Component to enable/disable Apache configuration."""
 
-    def __init__(self, component_id, web_name, kind='config', urls=None,
-                 expect_redirects=False, last_updated_version=None):
+    def __init__(self, component_id: str, web_name: str, kind: str = 'config',
+                 urls: list[str] | None = None, expect_redirects: bool = False,
+                 last_updated_version: int | None = None):
         """Initialize the web server component.
 
         component_id should be a unique ID across all components of an app and
@@ -35,6 +36,9 @@ class Webserver(app.LeaderComponent):
         urls is a list of URLs over which a HTTP services will be available due
         to this component. This list is only used for running diagnostics.
 
+        expect_redirects is a boolean that allows redirects when trying to
+        access the URLs during diagnosis of the component.
+
         last_updated_version is the app version in which the web server
         configuration/site/module file was updated. Using this, web server will
         be automatically reloaded or restarted as necessary during app upgrade.
@@ -47,15 +51,15 @@ class Webserver(app.LeaderComponent):
         self.expect_redirects = expect_redirects
         self.last_updated_version = last_updated_version or 0
 
-    def is_enabled(self):
+    def is_enabled(self) -> bool:
         """Return whether the Apache configuration is enabled."""
         return action_utils.webserver_is_enabled(self.web_name, kind=self.kind)
 
-    def enable(self):
+    def enable(self) -> None:
         """Enable the Apache configuration."""
         privileged.enable(self.web_name, self.kind)
 
-    def disable(self):
+    def disable(self) -> None:
         """Disable the Apache configuration."""
         privileged.disable(self.web_name, self.kind)
 
@@ -63,7 +67,6 @@ class Webserver(app.LeaderComponent):
         """Check if the web path is accessible by clients.
 
         See :py:meth:`plinth.app.Component.diagnose`.
-
         """
         results = []
         for url in self.urls:
@@ -79,7 +82,7 @@ class Webserver(app.LeaderComponent):
 
         return results
 
-    def setup(self, old_version):
+    def setup(self, old_version: int):
         """Restart/reload web server if configuration files changed."""
         if not old_version:
             # App is being freshly setup. After setup, app will be enabled
@@ -102,10 +105,115 @@ class Webserver(app.LeaderComponent):
             service_privileged.reload('apache2')
 
 
+class WebserverRoot(app.FollowerComponent):
+    """Component to enable/disable Apache configuration for domain root.
+
+    Each domain has a unique virtual host configuration in Apache. This file
+    includes an option configuration file that can dropped in by FreedomBox. If
+    an app wants to be hosted on a dedicated domain, it can provide a
+    configuration file that is meant to be in the <VirtualHost> section. Using
+    this component, the include file fragment for a selected domain can be
+    linked to app's configuration file. Then, for the selected domain, the
+    app's configuration becomes the domain's root configuration.
+
+    This components uses key/value store to remember the selected domain. When
+    the domain changes, the change must be notified using domain_set().
+    """
+
+    def __init__(self, component_id: str, web_name: str,
+                 expect_redirects: bool = False,
+                 last_updated_version: int | None = None):
+        """Initialize the web server component for domain root.
+
+        component_id should be a unique ID across all components of an app and
+        across all components.
+
+        web_name is the primary part of the configuration file path which must
+        be enabled/disabled by this component. The file's path should be
+        /etc/apache2/includes/<web_name>.conf.
+
+        expect_redirects is a boolean that allows redirects when trying to
+        access the domain URL during diagnosis of the component.
+
+        last_updated_version is the app version in which the web server
+        configuration/site/module file was updated. Using this, web server will
+        be automatically reloaded or restarted as necessary during app upgrade.
+        """
+        super().__init__(component_id)
+
+        self.web_name = web_name
+        self.expect_redirects = expect_redirects
+        self.last_updated_version = last_updated_version or 0
+
+    def enable(self) -> None:
+        """Link the Apache site root configuration to app configuration."""
+        domain = self.domain_get()
+        if domain:
+            privileged.link_root(domain, self.web_name)
+
+    def disable(self) -> None:
+        """Unlink the Apache site root configuration from app configuration."""
+        domain = self.domain_get()
+        if domain:
+            privileged.unlink_root(domain)
+
+    def _key_get(self) -> str:
+        """Return the key used to store the domain in kvstore."""
+        return f'{self.component_id}_domain'
+
+    def domain_get(self) -> str | None:
+        """Return the currently configured domain name."""
+        return kvstore.get_default(self._key_get(), None)
+
+    def domain_set(self, domain: str | None):
+        """Set the domain to use with the app."""
+        self.disable()
+        kvstore.set(self._key_get(), domain)
+        if self.app.is_enabled():
+            self.enable()
+
+    def diagnose(self) -> list[DiagnosticCheck]:
+        """Check if the site root path is accessible by clients.
+
+        See :py:meth:`plinth.app.Component.diagnose`.
+        """
+        results = []
+        domain = self.domain_get()
+        if domain:
+            results.append(
+                diagnose_url(f'https://{domain}', check_certificate=False,
+                             component_id=self.component_id))
+
+        return results
+
+    def setup(self, old_version: int):
+        """Restart/reload web server if configuration files changed."""
+        if not old_version:
+            # App is being freshly setup. After setup, app will be enabled
+            # which will result in reload/restart of web server.
+            return
+
+        if old_version >= self.last_updated_version:
+            # Already using the latest configuration. Web server reload/restart
+            # is not necessary.
+            return
+
+        if not self.app.is_enabled():
+            # App is currently disabled, web server will reloaded/restarted
+            # when the app is enabled.
+            return
+
+        service_privileged.reload('apache2')
+
+    def uninstall(self):
+        """Remove the domain configured."""
+        kvstore.delete(self._key_get(), ignore_missing=True)
+
+
 class Uwsgi(app.LeaderComponent):
     """Component to enable/disable uWSGI configuration."""
 
-    def __init__(self, component_id, uwsgi_name):
+    def __init__(self, component_id: str, uwsgi_name: str):
         """Initialize the uWSGI component.
 
         component_id should be a unique ID across all components of an app and
@@ -119,20 +227,20 @@ class Uwsgi(app.LeaderComponent):
 
         self.uwsgi_name = uwsgi_name
 
-    def is_enabled(self):
+    def is_enabled(self) -> bool:
         """Return whether the uWSGI configuration is enabled."""
         return action_utils.uwsgi_is_enabled(self.uwsgi_name) \
             and action_utils.service_is_enabled('uwsgi')
 
-    def enable(self):
+    def enable(self) -> None:
         """Enable the uWSGI configuration."""
         privileged.uwsgi_enable(self.uwsgi_name)
 
-    def disable(self):
+    def disable(self) -> None:
         """Disable the uWSGI configuration."""
         privileged.uwsgi_disable(self.uwsgi_name)
 
-    def is_running(self):
+    def is_running(self) -> bool:
         """Return whether the uWSGI daemon is running with configuration."""
         return action_utils.uwsgi_is_enabled(self.uwsgi_name) \
             and action_utils.service_is_running('uwsgi')
