@@ -59,15 +59,14 @@ class CalibreApp(app_module.App):
                                donation_url='https://calibre-ebook.com/donate')
         self.add(info)
 
-        menu_item = menu.Menu('menu-calibre', info.name,
-                              info.short_description, info.icon_filename,
-                              'calibre:index', parent_url_name='apps')
+        menu_item = menu.Menu('menu-calibre', info.name, info.icon_filename,
+                              info.tags, 'calibre:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut('shortcut-calibre', info.name,
-                                      short_description=info.short_description,
                                       icon=info.icon_filename, url='/calibre',
-                                      clients=info.clients,
+                                      clients=info.clients, tags=info.tags,
                                       login_required=True,
                                       allowed_groups=list(groups))
         self.add(shortcut)
