@@ -2,8 +2,7 @@
 """Provides privileged actions that run as root."""
 
 from .aliases import setup_aliases
-from .dkim import (get_dkim_public_key, setup_dkim,
-                   fix_incorrect_key_ownership)
+from .dkim import fix_incorrect_key_ownership, get_dkim_public_key, setup_dkim
 from .domain import set_domains
 from .home import setup_home
 from .postfix import setup_postfix
