@@ -3,10 +3,10 @@
 URLs for the quassel module.
 """
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from .views import QuasselAppView
 
 urlpatterns = [
-    url(r'^apps/quassel/$', QuasselAppView.as_view(), name='index'),
+    re_path(r'^apps/quassel/$', QuasselAppView.as_view(), name='index'),
 ]
